import logging
import click

from ..version import __version__

logging.basicConfig()
log = logging.getLogger(__name__)


@click.group(context_settings=dict(help_option_names=["-h", "--help"]))
@click.version_option(version=__version__)
def itksn():
    pass



import shlex
import itksn
import time


def test_version(script_runner):
    command = "itksn --version"
    start = time.time()
    ret = script_runner.run(*shlex.split(command))
    end = time.time()
    elapsed = end - start
    assert ret.success
    assert itksn.__version__ in ret.stdout
    assert ret.stderr == ""
    # make sure it took less than a second
    assert elapsed < 1.0



from setuptools import setup

extras_require = {}
extras_require["lint"] = sorted(set(["pyflakes", "black"]))
extras_require["test"] = sorted(
    set(
        [
            "check-manifest",
            "pytest~=6.0",
            "pytest-cov~=2.8",
            "pytest-console-scripts~=0.2",
            "pytest-mock~=3.0",
        ]
    )
)
extras_require["develop"] = sorted(
    set(
        extras_require["test"]
        + extras_require["lint"]
        + ["check-manifest", "bumpversion~=0.5", "pre-commit", "twine"]
    )
)
extras_require["complete"] = sorted(set(sum(extras_require.values(), [])))

setup(
    extras_require=extras_require,
    use_scm_version=lambda: {"local_scheme": lambda version: ""},
)
